@@ -19,11 +19,18 @@ def handle_list(
 
     if args.default:
         if is_superuser:
-            group_id = "0"
+            group_id = "default"
             message += "默认"
         else:
             return "获取默认插件列表需要超级用户权限！"
 
+    if args.private:
+        if is_superuser:
+            group_id = "0"
+            message += "私聊"
+        else:
+            return "获取私聊插件列表需要超级用户权限！"
+
     if args.group:
         if is_superuser:
             group_id = args.group
@@ -55,10 +62,17 @@ def handle_block(
 
     if args.default:
         if is_superuser:
-            group_id = "0"
+            group_id = "default"
             message += "默认"
         else:
             return "管理默认插件需要超级用户权限！"
+    
+    if args.private:
+        if is_superuser:
+            group_id = "0"
+            message += "私聊"
+        else:
+            return "管理私聊插件需要超级用户权限！"
 
     if args.group:
         if is_superuser:
@@ -90,10 +104,17 @@ def handle_unblock(
 
     if args.default:
         if is_superuser:
-            group_id = "0"
+            group_id = "default"
             message += "默认"
         else:
             return "管理默认插件需要超级用户权限！"
+    
+    if args.private:
+        if is_superuser:
+            group_id = "0"
+            message += "私聊"
+        else:
+            return "管理私聊插件需要超级用户权限！"
 
     if args.group:
         if is_superuser:
